##-----------------------------------------------------------------##
## Replication File
## "Fear of Nonviolent Organizing in Mexico's Criminal Conflict"
## Cassy Dorff and Jessica Braithwaite
## June 2018
##-----------------------------------------------------------------##

## Clearing workspace
rm(list=ls())

## Libraries
library(foreign)
library(xtable)
library(ggplot2)
library(apsrtable)
library(coefplot) 
library(gmodels)
library(ggthemes)

## Set up
setwd("")
source("multiplot.R")

##------------------------------------------------------------
## MAIN MANUSCRIPT
##------------------------------------------------------------
load("repData.rda")
## table 1 summary stats
library(pastecs)
stat.desc(repData)

## hist
load("appendix/repAppData2.rda")
hist(repAppData2$fearCatOrg)

## table 2 & 3, Cross tabs
repDataNaOmit<-na.omit(as.data.frame(repData))
CrossTable(repDataNaOmit$fearcat4, repDataNaOmit$muniauto, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)
CrossTable(repDataNaOmit$fearcat4, repDataNaOmit$gender, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)

##------------------------------------------------------------
## Main MS Results, Table 4
##------------------------------------------------------------

mod1<-lm(fearcat4
     ~ muniauto + gender + victimCardAA + victimCardBB + javier
     + lightbulbs + edu + age, data=repData)
mod2<-glm(fearNVlo
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repData)
mod3<-glm(fearNVmed
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repData)
mod4<-glm(fearNVhi
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repData)
apsrtable(mod1,mod2,mod3,mod4)

##------------------------------------------------------------
## MAIN MS Coefficient Plot, Fig 3
##------------------------------------------------------------

## Coefplot all models
allModels<-multiplot(mod1, mod2, mod3, mod4, title="", 
  xlab="", ylab="", intercept=FALSE, innerCI=1, outerCI=2, 
  lwdOuter=1, lwdInner=1.5, single=FALSE,
  names=c("Model 1: OLS", "Model 2: Any Fear", "Model 3: Moderate Fear", "Model 4: High Fear"),
     newNames=c(muniauto="Autodefensas", gender="Female", 
      victimCardAA="Low victimization",
      victimCardBB="High victimization", 
      javier="MPJD knowledge", lightbulbs="Lightbulbs",
      edu="education", age="Age"))
allModels<-allModels + theme_hc() + scale_colour_hc() #(fun colors)
#allModels<- allModels + theme_hc() + scale_colour_manual(values=c("gray10", "gray30", "gray60", "gray"))
allModels + theme(axis.ticks=element_blank(),
 axis.text.x = element_text(angle=0), legend.position="none")

##------------------------------------------------------------
## MAIN MS Marginal Effects, fig 4
##------------------------------------------------------------

#Model 2, any fear of victimization vs. autodefensas.
    predprob1 <- with(repData, data.frame(muniauto=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     gender=c(1),
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval1 <- predict(mod2,predprob1,type="response",se.fit=TRUE)
    probval1$lower <- probval1$fit - (1.96*probval1$se.fit)
    probval1$upper <- probval1$fit + (1.96*probval1$se.fit)
    probplot1 <- data.frame(muniauto=0:1,fit=probval1$fit,upper=probval1$upper,lower=probval1$lower)

    pp1<-ggplot(probplot1,aes(x=muniauto,y=fit)) +
        #geom_point(size=2) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
        xlab("Autodefensas (0=absent, 1=present)") +
        ylab("Pr(Any fear of victimization)")
    pp1<- pp1 + theme_minimal() +
          theme(panel.grid.minor=element_blank())

#Model 2, low fear of victimization vs. gender.
    predprob2 <- with(repData, data.frame(gender=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     muniauto=0,
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval2 <- predict(mod2,predprob2,type="response",se.fit=TRUE)
    probval2$lower <- probval2$fit - (1.96*probval2$se.fit)
    probval2$upper <- probval2$fit + (1.96*probval2$se.fit)
    probplot2 <- data.frame(gender=0:1,fit=probval2$fit,upper=probval2$upper,lower=probval2$lower)

    pp2<-ggplot(probplot2,aes(x=gender,y=fit)) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
        xlab("Gender (0=male, 1=female)") +
        ylab("Pr(Any fear of victimization)")
pp2<- pp2 + theme_minimal() +
          theme(panel.grid.minor=element_blank())

#Model 3, medium fear of victimization vs. autodefensas.
    predprob3 <- with(repData, data.frame(muniauto=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     gender=c(1),
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval3 <- predict(mod3,predprob3,type="response",se.fit=TRUE)
    probval3$lower <- probval3$fit - (1.96*probval3$se.fit)
    probval3$upper <- probval3$fit + (1.96*probval3$se.fit)
    probplot3 <- data.frame(muniauto=0:1,fit=probval3$fit,upper=probval3$upper,lower=probval3$lower)

    pp3<-ggplot(probplot3,aes(x=muniauto,y=fit)) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
        xlab("Autodefensas (0=absent, 1=present)") +
        ylab("Pr(Moderate fear of victimization)")
  pp3<- pp3 + theme_minimal() +
          theme(panel.grid.minor=element_blank())

#Model 3, med fear of victimization vs. gender.
    predprob4 <- with(repData, data.frame(gender=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     muniauto=c(0),
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval4 <- predict(mod3,predprob4,type="response",se.fit=TRUE)
    probval4$lower <- probval4$fit - (1.96*probval4$se.fit)
    probval4$upper <- probval4$fit + (1.96*probval4$se.fit)
    probplot4 <- data.frame(gender=0:1,fit=probval4$fit,upper=probval4$upper,lower=probval4$lower)

    pp4<-ggplot(probplot4,aes(x=gender,y=fit)) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
        xlab("Gender (0=male, 1=female)") +
        ylab("Pr(Moderate fear of victimization)")
  pp4<- pp4 + theme_minimal() +
          theme(panel.grid.minor=element_blank())

#Model 4, high fear of victimization vs. autodefensas.
    predprob5 <- with(repData, data.frame(muniauto=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     gender=c(1),
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval5 <- predict(mod4,predprob5,type="response",se.fit=TRUE)
    probval5$lower <- probval5$fit - (1.96*probval5$se.fit)
    probval5$upper <- probval5$fit + (1.96*probval5$se.fit)
    probplot5 <- data.frame(muniauto=0:1,fit=probval5$fit,upper=probval5$upper,lower=probval5$lower)

    pp5<-ggplot(probplot5,aes(x=muniauto,y=fit)) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
        xlab("Autodefensas (0=absent, 1=present)") +
        ylab("Pr(High fear of victimization)")

    pp5<- pp5 + theme_minimal() +
          theme(panel.grid.minor=element_blank())

#Model 4, high fear of victimization vs. gender.
    predprob6 <- with(repData, data.frame(gender=0:1,
                                     edu=mean(edu,na.rm=TRUE),
                                     muniauto=c(0),
                                     age=mean(age,na.rm=TRUE),
                                     victimCardAA=c(0),
                                     victimCardBB=c(0),
                                     javier=mean(javier,na.rm=TRUE),
                                     lightbulbs=mean(lightbulbs,na.rm=TRUE)
                                     ))

    probval6 <- predict(mod4,predprob6,type="response",se.fit=TRUE)
    probval6$lower <- probval6$fit - (1.96*probval6$se.fit)
    probval6$upper <- probval6$fit + (1.96*probval6$se.fit)
    probplot6 <- data.frame(gender=0:1,fit=probval6$fit,
        upper=probval6$upper,lower=probval6$lower)

    pp6<-ggplot(probplot6,aes(x=gender,y=fit)) +
        #geom_point(size=2) +
        geom_pointrange(aes(ymax=upper,ymin=lower),width=0.05) +
        geom_line() +
    xlab("Gender (0=male, 1=female)") +
        ylab("Pr(High fear of victimization)")

    pp6<- pp6 + theme_minimal() +
        theme(panel.grid.minor=element_blank())
multiplotG(pp1,pp2,pp3, pp4, pp5,pp6, cols=3)
