##-----------------------------------------------------------------##
## Replication File for Appendix
## "Appendix: Fear of Nonviolent Organizing in Mexico's Criminal Conflict"
## Cassy Dorff and Jessica Braithwaite
## June 2018
##-----------------------------------------------------------------##

## Clearing workspace
rm(list=ls())

## Libraries
library(foreign)
library(xtable)
library(ggplot2)
library(apsrtable)
library(coefplot) 
library(gmodels)
library(ggthemes)
library(pastecs)


## Load Data
setwd("")
source("multiplot.R")

####------------------------------------------------------------
## APPENDIX
####------------------------------------------------------------

load("repAppData.rda")

# table a1
stat.desc(repAppData)
# table a2
repAppDataNaOmit<-na.omit(as.data.frame(repAppData))
CrossTable(repAppDataNaOmit$fearcat4, repAppDataNaOmit$muniauto, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)
#table a3
CrossTable(repAppDataNaOmit$fearcat4, repAppDataNaOmit$gender, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)

##------------------------------------------------------------
## Appendix Results with oversample, Table A4
##------------------------------------------------------------

mod1A<-lm(fearcat4
     ~ muniauto + gender + victimCardAA + victimCardBB + javier
     + lightbulbs + edu + age, data=repAppData)
mod2A<-glm(fearNVlo
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
mod3A<-glm(fearNVmed
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
mod4A<-glm(fearNVhi
    ~ muniauto + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
apsrtable(mod1A,mod2A,mod3A,mod4A)

##------------------------------------------------------------
## Appendix Coefficient Plot, Fig A1
##------------------------------------------------------------

allModelsA<-multiplot(mod1A, mod2A, mod3A, mod4A, title="", 
  xlab="", ylab="", intercept=FALSE, innerCI=1, outerCI=2, 
  lwdOuter=1, lwdInner=1.5, single=FALSE,
  names=c("Model 1: OLS", "Model 2: Any Fear", "Model 3: Moderate Fear", "Model 4: High Fear"),
     newNames=c(muniauto="Autodefensas", gender="Female", 
      victimCardAA="Low victimization",
      victimCardBB="High victimization", 
      javier="MPJD knowledge", lightbulbs="Lightbulbs",
      edu="education", age="Age"))
allModelsA<-allModelsA + theme_hc() + scale_colour_hc() #(fun colors)
allModelsA + theme(axis.ticks=element_blank(),
 axis.text.x = element_text(angle=0), legend.position="none")

##------------------------------------------------------------
## Appendix Results, replication of A4 with inclusion & control for oversample
##------------------------------------------------------------

mod1AB<-lm(fearcat4
     ~ oversample + gender + victimCardAA + victimCardBB + javier
     + lightbulbs + edu + age, data=repAppData)
mod2AB<-glm(fearNVlo
    ~ oversample + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
mod3AB<-glm(fearNVmed
    ~ oversample + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
mod4AB<-glm(fearNVhi
    ~ oversample + gender + victimCardAA + victimCardBB + javier 
    + lightbulbs + edu + age, family=binomial(link='logit'),
    data=repAppData)
apsrtable(mod1AB,mod2AB,mod3AB,mod4AB)

##------------------------------------------------------------
## Replication of MS' Table 4 varying key IVs (Table A6 and A7)
##------------------------------------------------------------
repAppDataNat<-repAppData[repAppData$"oversample"==0,]

table4Auto<-lm(fearcat4
     ~ muniauto, data=repAppDataNat)
table4Women<-lm(fearcat4
     ~ muniauto + gender, data=repAppDataNat)
table4Vic<-lm(fearcat4
     ~ muniauto + gender + victimCardAA + victimCardBB, 
     data=repAppDataNat)

table4Auto.2<-glm(fearNVlo
    ~ muniauto, family=binomial(link='logit'),
    data=repAppDataNat)
table4Women.2<-glm(fearNVlo
    ~ muniauto + gender, family=binomial(link='logit'),
    data=repAppDataNat)
table4Vic.2<-glm(fearNVlo
    ~ muniauto + gender + victimCardAA + victimCardBB, family=binomial(link='logit'),
    data=repAppDataNat)

table4Auto.3<-glm(fearNVmed
    ~ muniauto, family=binomial(link='logit'),
    data=repAppDataNat)
table4Women.3<-glm(fearNVmed
    ~ muniauto + gender, family=binomial(link='logit'),
    data=repAppDataNat)
table4Vic.3<-glm(fearNVmed
    ~ muniauto + gender + victimCardAA + victimCardBB, family=binomial(link='logit'),
    data=repAppDataNat)

table4Auto.4<-glm(fearNVhi
    ~ muniauto, family=binomial(link='logit'),
    data=repAppDataNat)
table4Women.4<-glm(fearNVhi
    ~ muniauto + gender, family=binomial(link='logit'),
    data=repAppDataNat)
table4Vic.4<-glm(fearNVhi
    ~ muniauto + gender + victimCardAA + victimCardBB, family=binomial(link='logit'),
    data=repAppDataNat)

##------------------------------------------------------------
## Model Robustness Check: Alternative DV Specifications
##------------------------------------------------------------
load("repAppData2.rda")
repAppDataNat2<-repAppData2[repAppData2$"oversample"==0,]

# fig A2, barplot 
names<-c("None", "Not Sure", "A little", "Some", "A lot")
barplot(table(repAppDataNat2$fearAll), xlab="Levels of Fear", names=names)

# table A8
modDV<-lm(fearAll
    ~ muniauto + gender + victimCardAA + victimCardBB + javier
     + lightbulbs + edu + age, data=repAppDataNat2, na.action=na.exclude)

# table A9 
mod1Assault<-lm(fearCA
    ~ muniauto + gender + victimCardAA + victimCardBB + javier
     + lightbulbs + edu + age, data=repAppDataNat2, na.action=na.exclude)

##------------------------------------------------------------
## Gender, fear, social desirability bias
##------------------------------------------------------------

# table A10
table(repAppDataNat2$gender,repAppDataNat2$victimCardAA)
CrossTable(repAppDataNat2$gender, repAppDataNat2$victimCardAA, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)
CrossTable(repAppDataNat2$gender, repAppDataNat2$victimCardBB, digits=3, prop.c=TRUE, prop.t=FALSE,
  prop.r=FALSE, prop.chisq=FALSE)

# fig A3 and A4
barplot(prop.table(table(repAppDataNat2$gender,
  repAppDataNat2$fearCA)), names=c("None","A little","Some","A lot"),
  beside=T,
  #main="Levels of Fear of Physical Assault by Gender",
  xlab="Levels of Fear",
  legend=TRUE, args.legend=list(bty="n", x="topleft"))

barplot(prop.table(table(repAppDataNat2$gender,
  repAppDataNat2$fearCSE)),
  beside=T, names=c("None","A little","Some","A lot"),
  #main="Levels of Fear of Sexual Assault by Gender",
    xlab="Levels of Fear",
  legend=TRUE, args.legend=list(bty="n", x="topleft")
  )

##------------------------------------------------------------
# robustness check, table A11
##------------------------------------------------------------
mod1J<-lm(fearcat4
     ~ muniauto + gender + victimCardAA + victimCardBB + javierB
     + lightbulbs + edu + age, data=repAppDataNat2)

